% ------------------------------------------------------------------------------
% Book:        SFS
% ------------------------------------------------------------------------------
% Quantlet:    SFSstoploss
% ------------------------------------------------------------------------------
% Description: SFSstoploss calculates the Black-Scholes call price of a stock and
%              produces a table of the costs of hedging.
%
%              Refers to exercise 6.3 in SFS.
% ------------------------------------------------------------------------------
% Usage:       -
% ------------------------------------------------------------------------------
% Inputs:      None.
% ------------------------------------------------------------------------------
% Output:      Call price, table of costs of hedging.
% ------------------------------------------------------------------------------
% Example:     -
% ------------------------------------------------------------------------------
% Author:      R: Derrick Kanngiesser 20120403
%              Matlab: Awdesch Melzer 20130123
% ------------------------------------------------------------------------------

clear all
close all
clc


%%%%%    Calculates the price of the call

S           = [49,49.75,52,50,48.37,48.25,48.75,49.62,48.25,48.25,51.12, ...
    51.50,49.87,49.87,48.75,47.50,48.00,46.25,48.12,46.62,48.12]';
% Stockprice
K           = 50;      % Exercise price
tau         = 0.3846; % 20 weeks of time to maturity
r           = 0.05;    % Interest rate
sigma       = 0.20; % Volatility
n           = 100000;   % 


% If you use Matlab version of blsprice, please, uncomment:
% [C P]      = blsprice(S, K, r, tau, sigma);
% else if you use function from quantnet:
 [C P]     = blsprice(S, K, r, sigma,tau);

%%%%%   Calculates the cost of hedging
% start with 49 under a) and 51 under b)
stockprices = [49,49.75,52,50,48.37,48.25,48.75,49.62,48.25,48.25,51.12, ...
    51.50,49.87,49.87,48.75,47.50,48.00,46.25,48.12,46.62,48.12]';

% generate time vector
time        = [-1:20]';

% generate dummy variable vector to test if stock price crosses K=50, 1==yes, 0==no
S = [0; stockprices];
D = [0; S]; % vector has to start with a zero (or any number smaller than 50) in order to impose action in case the first value is greater than 50
Hedge_strat = (D>50);

% hedging takes place if element changes from 0 to 1 or vice versa
% from 0 to 1 purchase
Shares_purchase = (diff(Hedge_strat)==1)*100000;
Shares_purchase

% from 1 to 0 sell
Shares_sold = (diff(Hedge_strat)==(-1))*(-100000);
Shares_sold

% Cost of shares, multiply number of shares (bought) with corresponding price
Cost_shares = Shares_purchase.*S;

% Revenue of shares, multiply number of shares (sold) with corresponding price
Revenue_shares = Shares_sold.*S;

% Cumulative Costs
cumucosts = 0;
for (i = 2:(length(Cost_shares)))
     	cumucosts(i) = cumucosts(i-1) + Cost_shares(i) + Revenue_shares(i);
end
cumucosts = cumucosts';

% Table of costs
tablefull = [time,S,Hedge_strat(2:23),Shares_purchase,Cost_shares,Revenue_shares,cumucosts];
tablefull(1,:) = [];
table = tablefull;

disp('Table of costs of hedging')
disp('      Time       S    H_stat  Shares_pur  Cost_share  Revenue_s  Cum_costs')
table
