% ---------------------------------------------------------------------
% Book:        SFS
% ---------------------------------------------------------------------
% Quantlet:    SFSstrap
% ---------------------------------------------------------------------
% Description: SFSstrap plots a strap option strategy. It uses a long 
%              position in one put and two (or more) calls in
%              anticipation of upward price movement. Values can be 
%              entered interactively. Refers to exercise 1.9 in SFS.
% ---------------------------------------------------------------------
% Usage:       SFSstrap
% ---------------------------------------------------------------------
% Inputs:      St    - Stock price
%              K1    - Strike price
%              r     - Interest rate
%              T     - Time to expiration
%              sigma - Volatility
%              N     - Ratio of long calls to long puts
% ---------------------------------------------------------------------
% Output:      Plot of a strap option strategy
% ---------------------------------------------------------------------
% Example:     An example is produced for the values: St=20, K1=25,
%              T=1, sigma = 0.5, r=0.03, N = 2.
% ---------------------------------------------------------------------
% Author:      Lasse Groth 20090716
% ---------------------------------------------------------------------

clear
clc
close all

disp('Please input St, K1, T, sigma, r, N  as: [20,25,1,0.5,0.03,2]') ;
disp(' ') ;
para=input('[St, K1, T, sigma, r, N]=');

while length(para) < 6
    disp(' ')
    disp('Not enough input arguments. Please input in 1*6 vector form like [20,25,1,0.5,0.03,2]');
    para=input('[St, K1, T, sigma, r, N]=');
end

St=para(1); %Set the parameters
K1=para(2);
T=para(3);
sigma=para(4);
r=para(5);
N=para(6);

K2=2*K1;  %Upper boundary for plot

[Call, Put]=blsprice(St,K1,r,T,sigma); %Calculate the plain vanilla option prices

x=[0;K1;K2];  %Set the coordinates
    
y1=N*[(-Call)*exp(r*T); (-Call)*exp(r*T); (-Call)*exp(r*T)+(K2-K1)];  %Calculate the payoff at each coordinate
y2=[(-Put)*exp(r*T)+(K2-K1);(-Put)*exp(r*T);(-Put)*exp(r*T)];

y = y1+y2;  %Combine the payoffs of options to get the strap strategy

hold on
plot(x,y,'-r','LineWidth',2)
plot(x,y1, '--k', 'LineWidth', 1)
plot(x,y2, '--k', 'LineWidth', 1)
plot(x,zeros(1,3),':k','LineWidth',0.2)
hold off

axis([0 x(3,:) y(2,:)*1.1 y(3,:)*1.1])
xlabel('S_T');      
ylabel('Payoff');
title('Strap');
 
     % ---------------------------------------------------------------------
% Book:        SFS
% ---------------------------------------------------------------------
% Quantlet:    SFSstrap
% ---------------------------------------------------------------------
% Description: SFSstrap plots a strap option strategy. It uses a long 
%              position in one put and two (or more) calls in
%              anticipation of upward price movement. Values can be 
%              entered interactively. Refers to exercise 1.9 in SFS.
% ---------------------------------------------------------------------
% Usage:       SFSstrap
% ---------------------------------------------------------------------
% Inputs:      St    - Stock price
%              K1    - Strike price
%              r     - Interest rate
%              T     - Time to expiration
%              sigma - Volatility
%              N     - Ratio of long calls to long puts
% ---------------------------------------------------------------------
% Output:      Plot of a strap option strategy
% ---------------------------------------------------------------------
% Example:     An example is produced for the values: St=20, K1=25,
%              T=1, sigma = 0.5, r=0.03, N = 2.
% ---------------------------------------------------------------------
% Author:      Lasse Groth 20090716
% ---------------------------------------------------------------------

clear
clc
close all

disp('Please input St, K1, T, sigma, r, N  as: [20,25,1,0.5,0.03,2]') ;
disp(' ') ;
para=input('[St, K1, T, sigma, r, N]=');

while length(para) < 6
    disp(' ')
    disp('Not enough input arguments. Please input in 1*6 vector form like [20,25,1,0.5,0.03,2]');
    para=input('[St, K1, T, sigma, r, N]=');
end

St=para(1); %Set the parameters
K1=para(2);
T=para(3);
sigma=para(4);
r=para(5);
N=para(6);

K2=2*K1;  %Upper boundary for plot

[Call, Put]=blsprice(St,K1,r,T,sigma); %Calculate the plain vanilla option prices

x=[0;K1;K2];  %Set the coordinates
    
y1=N*[(-Call)*exp(r*T); (-Call)*exp(r*T); (-Call)*exp(r*T)+(K2-K1)];  %Calculate the payoff at each coordinate
y2=[(-Put)*exp(r*T)+(K2-K1);(-Put)*exp(r*T);(-Put)*exp(r*T)];

y = y1+y2;  %Combine the payoffs of options to get the strap strategy

hold on
plot(x,y,'-r','LineWidth',2)
plot(x,y1, '--k', 'LineWidth', 1)
plot(x,y2, '--k', 'LineWidth', 1)
plot(x,zeros(1,3),':k','LineWidth',0.2)
hold off

axis([0 x(3,:) y(2,:)*1.1 y(3,:)*1.1])
xlabel('S_T');      
ylabel('Payoff');
title('Strap');
 
     % ---------------------------------------------------------------------
% Book:        SFS
% ---------------------------------------------------------------------
% Quantlet:    SFSstrap
% ---------------------------------------------------------------------
% Description: SFSstrap plots a strap option strategy. It uses a long 
%              position in one put and two (or more) calls in
%              anticipation of upward price movement. Values can be 
%              entered interactively. Refers to exercise 1.9 in SFS.
% ---------------------------------------------------------------------
% Usage:       SFSstrap
% ---------------------------------------------------------------------
% Inputs:      St    - Stock price
%              K1    - Strike price
%              r     - Interest rate
%              T     - Time to expiration
%              sigma - Volatility
%              N     - Ratio of long calls to long puts
% ---------------------------------------------------------------------
% Output:      Plot of a strap option strategy
% ---------------------------------------------------------------------
% Example:     An example is produced for the values: St=20, K1=25,
%              T=1, sigma = 0.5, r=0.03, N = 2.
% ---------------------------------------------------------------------
% Author:      Lasse Groth 20090716
% ---------------------------------------------------------------------

clear
clc
close all

disp('Please input St, K1, T, sigma, r, N  as: [20,25,1,0.5,0.03,2]') ;
disp(' ') ;
para=input('[St, K1, T, sigma, r, N]=');

while length(para) < 6
    disp(' ')
    disp('Not enough input arguments. Please input in 1*6 vector form like [20,25,1,0.5,0.03,2]');
    para=input('[St, K1, T, sigma, r, N]=');
end

St=para(1); %Set the parameters
K1=para(2);
T=para(3);
sigma=para(4);
r=para(5);
N=para(6);

K2=2*K1;  %Upper boundary for plot

[Call, Put]=blsprice(St,K1,r,T,sigma); %Calculate the plain vanilla option prices

x=[0;K1;K2];  %Set the coordinates
    
y1=N*[(-Call)*exp(r*T); (-Call)*exp(r*T); (-Call)*exp(r*T)+(K2-K1)];  %Calculate the payoff at each coordinate
y2=[(-Put)*exp(r*T)+(K2-K1);(-Put)*exp(r*T);(-Put)*exp(r*T)];

y = y1+y2;  %Combine the payoffs of options to get the strap strategy

hold on
plot(x,y,'-r','LineWidth',2)
plot(x,y1, '--k', 'LineWidth', 1)
plot(x,y2, '--k', 'LineWidth', 1)
plot(x,zeros(1,3),':k','LineWidth',0.2)
hold off

axis([0 x(3,:) y(2,:)*1.1 y(3,:)*1.1])
xlabel('S_T');      
ylabel('Payoff');
title('Strap');
 
     