% ---------------------------------------------------------------------
% Book:         SFS
% ---------------------------------------------------------------------
% Quantlet:     SFStailport
% ---------------------------------------------------------------------
% Description:  SFStailport plots the right tail of the logarithmic 
%               empirical distribution of the portfolio (Bayer, BMW, 
%               Siemens) returns from 1992-01-01 to 2006-09-21.
% ---------------------------------------------------------------------
% Usage:        SFStailport
% ---------------------------------------------------------------------
% Inputs:       None
% ---------------------------------------------------------------------
% Output:       Right tail of the logarithmic empirical distribution of 
%               the portfolio (Bayer, BMW, Siemens).
% ---------------------------------------------------------------------
% Example:      -
% ---------------------------------------------------------------------
% Author:       Barbara Choros 20080730
% ---------------------------------------------------------------------

clc
clear
close all

a=load('Bay9906_close_2kPoints.txt','-ascii');
b=load('Bmw9906_close_2kPoints.txt','-ascii');
c=load('Sie9906_close_2kPoints.txt','-ascii');
d=a+b+c;
x=log(d(1:(end-1),:)./d(2:end,:)); %negative log-returns
n=length(x);
x=sort(x,'descend');
m=100;

% Generalized least squares method
x=x(1:m,:); 
x1=[ones(m,1),x];
y1=log((1:m)/n);
g=inv(x1'*x1)*(x1'*y1');

line=g(1,:)+g(2,:)*x;
alpha=-g(2,:);
gamma=1/alpha;
out=[x,line];

hold on
plot(out(:,1), out(:,2), 'k', 'LineWidth', 1.5)
scatter(x,y1)
title('Tail Index Regression of Portfolio')
xlabel('Log X')
ylabel('Log i/n')
hold off 