% ---------------------------------------------------------------------
% Book:         SFS
% ---------------------------------------------------------------------
% Quantlet:     SFStimeseries
% ---------------------------------------------------------------------
% Description:  
% ---------------------------------------------------------------------
% Usage:        depends on autocorr.m
% ---------------------------------------------------------------------
% Inputs:      - None
% ---------------------------------------------------------------------
% Output:       Plot of sample path for the random variable X_t
% ---------------------------------------------------------------------
% Example:      Perform an empirical analysis using the data on DAX and
%Dow Jones index from the period Jan. 1, 1997 to Dec. 30, 2004.
% ---------------------------------------------------------------------
% Author:       20090914
% ---------------------------------------------------------------------
% 

clear
close all
clc

%Load dataset
load 'daxdow.txt';

dax = daxdow(:,1);
dow = daxdow(:,2);

%Compute differences/returns
%daxret = price2ret(dax,[],'Periodic');
%dowret = price2ret(dow,[],'Periodic'); 

daxret = diff(dax);
dowret = diff(dow); 

%Log-returns
daxretlog = diff(log(dax));
dowretlog = diff(log(dow)); 

%Absolute log-returns
daxretlogabs = abs(daxretlog);
dowretlogabs = abs(dowretlog);

%Compute the ACF for DAX absolute log-returns, squared returns and 
%log-returns with 95% confidence interval.
e1_dax = autocorr(daxretlogabs,[],2);
e2_dax = autocorr(daxretlog.^2);
e3_dax = autocorr(daxretlog);
e4_dax = mean(daxretlog);

%Compute the ACF for Dow Jones absolute log-returns, squared returns and
%log-returns with 95% confidence interval.
e1_dow = autocorr(dowretlogabs,[],2);
e2_dow = autocorr(dowretlog.^2);
e3_dow = autocorr(dowretlog);
e4_dow = mean(dowretlog);

E_Dax = [e4_dax skewness(daxretlog) kurtosis(daxretlog) e3_dax(2) e2_dax(2) e1_dax(2)];
E_Dow = [e4_dow skewness(dowretlog) kurtosis(dowretlog) e3_dow(2) e2_dow(2) e1_dow(2) ];

%Display the mean, skewness, kurtosis, autocorrelation for log-returns,
%squarred log-returns and absolute returns for the DAX and Dow Jones index.
disp('DAX')
disp('    Mean     Skewness    Kurt.  ACF r_t    ACF r_t^2  ACF abs(r_t)')
disp(E_Dax)
disp(' ')
disp('Dow Jones Industrial Average')
disp('    Mean     Skewness    Kurt.  ACF r_t    ACF r_t^2  ACF abs(r_t)')
disp(E_Dow)

%Plot DAX / Dow absolute values
figure
    subplot(2,1,1); plot(dax, '-r')
        title('Dax Index')
        axis([0 2023 min(dax) max(dax)])
        set(gca,'XLim',[0 2000])
        set(gca,'XTick', [0 252 505 758 1011 1264 1517 1770 2000])
        months = ['1997';'1998';'1999';'2000';'2001';'2002';'2003';'2004';'2005'];
        set(gca,'XTickLabel',months)

    subplot(2,1,2); plot(dow)
        title('Dow Jones Index')
        axis([0 2023 min(dow) max(dow)])
        set(gca,'XLim',[0 2000])
        set(gca,'XTick', [0 252 505 758 1011 1264 1517 1770 2000])
        months = ['1997';'1998';'1999';'2000';'2001';'2002';'2003';'2004';'2005'];
        set(gca,'XTickLabel',months)
        
%Plot DAX / Dow returns
figure
    subplot(2,1,1); plot(daxret, '-r')
        title('Dax Index returns')
        axis([0 2023 min(daxret) max(daxret)])
        set(gca,'XLim',[0 2000])
        set(gca,'XTick', [0 252 505 758 1011 1264 1517 1770 2000])
        months = ['1997';'1998';'1999';'2000';'2001';'2002';'2003';'2004';'2005'];
        set(gca,'XTickLabel',months)
        
    subplot(2,1,2); plot(dowret, '-b')
        title('Dow Jones Index returns')
        axis([0 2023 min(dowret) max(dowret)])
        set(gca,'XLim',[0 2000])
        set(gca,'XTick', [0 252 505 758 1011 1264 1517 1770 2000])
        months = ['1997';'1998';'1999';'2000';'2001';'2002';'2003';'2004';'2005'];
        set(gca,'XTickLabel',months)
        
%Plot DAX / Dow log-returns
figure
    subplot(2,1,1); plot(daxretlog, '-r')
        title('Dax Index log-returns')
        axis([0 2023 min(daxretlog) max(daxretlog)])
        set(gca,'XLim',[0 2000])
        set(gca,'XTick', [0 252 505 758 1011 1264 1517 1770 2000])
        months = ['1997';'1998';'1999';'2000';'2001';'2002';'2003';'2004';'2005'];
        set(gca,'XTickLabel',months)
        
    subplot(2,1,2); plot(dowretlog, '-b')
        title('Dow Jones Index log-returns')
        axis([0 2023 min(dowretlog) max(dowretlog)])
        set(gca,'XLim',[0 2000])
        set(gca,'XTick', [0 252 505 758 1011 1264 1517 1770 2000])
        months = ['1997';'1998';'1999';'2000';'2001';'2002';'2003';'2004';'2005'];
        set(gca,'XTickLabel',months)
        
%Plot DAX / Dow sample ACF for log-returns
figure
    subplot(2,1,1); 
        autocorr(daxretlog, [], 2)
        title('Dax returns sample ACF')

    subplot(2,1,2); 
        autocorr(dowretlog, [], 2)
        title('Dow Jones returns sample ACF')

%Plot DAX / Dow ACF of squared log-return
figure
    subplot(2,1,1);
        autocorr(daxretlogabs, 30, 2)
        title('ACF of absolute returns Dax')

    subplot(2,1,2);
        autocorr(dowretlogabs, 30, 2)
        title('ACF of absolute returns Dow')

%Kernel Density Estimation
figure
[f, xi] = ksdensity(daxretlog);

f2 = daxretlog;
xi2 = normpdf((daxretlog-mean(daxretlog))/std(daxretlog))/std(daxretlog)';

d = [f2 xi2];
d = sortrows(d);
subplot(2,1,1); 

hold on
plot(xi, f, '-r', 'LineWidth', 2)
plot(d(:,1), d(:,2), '--k')
hold off
grid on
title('Kernel density estimation Dax')

[f, xi] = ksdensity(dowretlog);

f2 = dowretlog;
xi2 = normpdf((dowretlog-mean(dowretlog))/std(dowretlog))/std(dowretlog)';

d = [f2 xi2];
d = sortrows(d);

subplot(2,1,2);

hold on
plot(xi, f, 'LineWidth', 2)
plot(d(:,1), d(:,2), '--k')
hold off
grid on
title('Kernel density estimation Dow')

