% ---------------------------------------------------------------------
% Book:         SFS
% ---------------------------------------------------------------------
% Quantlet:     SFSwiener1
% ---------------------------------------------------------------------
% Description:  Simulates a Wiener Process Wt
% ---------------------------------------------------------------------
% Usage:        SFSwiener1
% ---------------------------------------------------------------------
% Inputs:       dt - Delta t
% ---------------------------------------------------------------------
% Output:       plot of Wiener Process
% ---------------------------------------------------------------------
% Example:      for dt=1, a Wiener Process with 1000 points is 
%               generated
% ---------------------------------------------------------------------
% Notes         Plug in delta t:  1, 0.5, 0.25, ... to see how the
%               limiting process works. 
% ---------------------------------------------------------------------
% Author:       Vladimir Georgescu
% ---------------------------------------------------------------------

clear
% user inputs parameters
disp('Please input Delta t') ;
disp(' ') ;
para=input('Delta t=');
while length(para) < 1
  disp('Not enough input arguments. Please input Delta t');
  para=input('Delta t=');
end
dt=para(1);
disp(' ') ;

% main calculation
l=1;
n=floor(l/dt);
t=0:dt:n*dt; 

randseed(0);
z=unifrnd(0,1,n,1);
z=2*(z>0.5)-1;
z=z*sqrt(dt);  %//to get finite and non-zero varinace

x=[0;cumsum(z)];
listik=[t',x];

% output
plot(listik(:,1),listik(:,2))

%title('Wiener process')
xlabel('Time')
ylabel('Values of process X_t')