% ---------------------------------------------------------------------
% Book:         SFS
% ---------------------------------------------------------------------
% Quantlet:     SFSwiener2
% ---------------------------------------------------------------------
% Description:  Simulates a Wiener Process Xt=c^(-0.5)*Wct
% ---------------------------------------------------------------------
% Usage:        SFSwiener2
% ---------------------------------------------------------------------
% Inputs:       dt - Delta t
%               c - Constant
% ---------------------------------------------------------------------
% Output:       plot of a Wiener Process Xt=c^(-0.5)*Wct
% ---------------------------------------------------------------------
% Example:      for dt=1, c=2 a Wiener Process Xt=1/sqrt(2)*W(2t) is 
%               shown
% ---------------------------------------------------------------------
% Notes         Plug in delta t:  1, 0.5, 0.25, ... to see how the 
%               limiting process works. 
% ---------------------------------------------------------------------
% Author:       Vladimir Georgescu
% ---------------------------------------------------------------------

clear
disp('Please input Delta t, Constant c as: [1,2]') ;
disp(' ') ;
para=input('[Delta t, Constant c]=');
while length(para) < 2
  disp('Not enough input arguments. Please input in 1*2 vector form like [1,2] or [1 2]');
  para=input('[Delta t, Constant c]=');
end
dt=para(1);
c=para(2);
disp(' ') ;

% main calculation
l=2000;
n=floor(l/dt);
t=0:c*dt:n*dt; 

randseed(0);
z=unifrnd(0,1,floor(n/c),1); 
z=2*(z>0.5)-1;
z=z*c^(-0.5)*sqrt(dt);  %//to get finite and non-zero variance

x=[0;cumsum(z)];
listik=[t',x];

% output
plot(listik(:,1),listik(:,2))

title('Wiener process')
xlabel('Time')
ylabel('Values of process X_t')