% ---------------------------------------------------------------------
% Book:         SFS
% ---------------------------------------------------------------------
% Quantlet:     SFSwiener3
% ---------------------------------------------------------------------
% Description:  Simulates a Wiener Process Yt=W(T+t)-WT, for T>0
% ---------------------------------------------------------------------
% Usage:        -
% ---------------------------------------------------------------------
% Inputs:       T - initial number of periods 
%               t - number of periods after T
% ---------------------------------------------------------------------
% Output:       Plot of a Wiener Process Yt=WT+t-WT, for T>0
% ---------------------------------------------------------------------
% Example:      for T=100, t=50  a Wiener Process Yt=W(150)-W(100) is  
%               shown
% ---------------------------------------------------------------------
% Author:       Vladimir Georgescu
% ---------------------------------------------------------------------

clear
close all 
clc

disp('Time index T and Time index t  as: [100,50]') ;
disp(' ') ;
para=input('[Time index T, Time index t]=');
while length(para) < 2
  disp('Not enough input arguments. Please input in 1*2 vector form like [100,50] or [100 50]');
  para=input('[Time index T, Time index t]=');
end

T=para(1);
t=para(2);
disp(' ') ;

%Main calculation
l=T+t;
g=0:l; 

randseed(0);
z=unifrnd(0,1,l,1);
z=2*(z>0.5)-1;
x=[0;cumsum(z)];

listik=[g',x];

% output
plot(listik(T+1:T+t+1,1),listik(T+1:T+t+1,2)) 

title('Wiener process')
xlabel('Time')
ylabel('Values of process Y_t')
