# ------------------------------------------------------------------------------
# Book:        SFS
# ------------------------------------------------------------------------------
# Quantlet:    SFScompBS
# ------------------------------------------------------------------------------
# Description: SFScompBS calculates and compares the price of a plain vanilla 
# call option with a power call option. Refers to exercise 9.11 in SFS.
# ------------------------------------------------------------------------------
# Usage:       -
# ------------------------------------------------------------------------------
# Inputs:      K - Strike price
#              S1, S2 - Stock possible prices
#              sigma - Volatilities
#              rho - correlation
#              r - Interest rate
#              tau - Time to maturity
#		   alpha - 
# ------------------------------------------------------------------------------
# Output:      The price of a vanilla call option and power call option.
# ------------------------------------------------------------------------------
# Example:     The example is produced for the values K=10, S1=10, S2=15, 
#              sigma=0.22, , r=0.02, tau=1.5, alpha=2. The price of the vanilla
#              call option and power call option is ___ and ___ respectively.
# ------------------------------------------------------------------------------
# Author:      Derrick Kanngiesser, 20120215
# ------------------------------------------------------------------------------

rm(list=ls(all=TRUE))

K <- 10
S <- 15 # 10 for ATM vanilla # 15 for ITM vanilla
sigma <- 0.22 # volatility
r <- 0.02
tau <- 1.5
alpha <- 2

#calculation of BS power call option

z <- (log(S/(K^(1/alpha)))  +(r-(1/2)* sigma^2)  ) / (sigma * sqrt(tau))
zz <- z + alpha*sigma*sqrt(tau)

p <- pnorm(z)
pp <- pnorm(zz)

C1 <- S^(alpha) * exp((alpha -1)*(r +0.5*alpha*sigma^2)*tau) *pp - K* exp(-r*tau) * p

# calculation of BS plain vanilla european call option

d<-exp(-(tau/4)*r)+exp(-(tau/2)*r)

y<-(log(S/K)+(r-sigma^2/2)*tau)/(sigma*sqrt(tau))
cdfy<-pnorm(y)
cdfn<-pnorm(y+sigma*sqrt(tau))

cdfy
cdfn

C2 <- S*cdfn-(K*exp(-r*tau)*cdfy)
C2
