# ------------------------------------------------------------------------------
# Book:        SFS
# ------------------------------------------------------------------------------
# Quantlet:    SFSgreeks
# ------------------------------------------------------------------------------
# Description: SFSgreeks calculates the delta, the gamma and the theta of a 
#              portfolio.
#              Refers to exercise 6.8 in SFS.
# ------------------------------------------------------------------------------
# Usage:       -
# ------------------------------------------------------------------------------
# Inputs:      K - Strike price
#              S - Stock price
#              r - Interest rate
#              sigma - Volatility
#              tau - Time to maturity
# ------------------------------------------------------------------------------
# Output:      The delta, the gamma and the theta of a portfolio.
# ------------------------------------------------------------------------------
# Example:     For [stock price, strike price, interest rate, volatility sigma, 
#              time to maturity]=[220, 220, 0.06, 0.25, 1/2 ], [delta, gamma, 
#              theta] of call to be longed is given [0.6018, 0.0099, -21.827].
#              For [stock price, strike price, interest rate, volatility sigma, 
#              time to maturity]=[220, 220, 0.06, 0.25, 1/4 ], [delta, gamma, 
#              theta] of call to be shorted is given [-0.5724, -0.0143, -28.379].
#              The overall [delta, gamma, theta] of portfolio is given
#              [0.0294, -0.0043, -50.206].
# ------------------------------------------------------------------------------
# Author:      Zografia Anastasiadou, 20110221
# ------------------------------------------------------------------------------

rm(list=ls(all=TRUE))	# Clear variables

setwd("C:/...")	# Please change working directory

K = 220			# Set strike price
S = 220			# Set stock price
tau1 = 6/12		# Set time of maturity of call to be longed
tau2 = 3/12		# Set time of maturity of call to be shorted
r = 0.06			# Set interest rate
sigma = 0.25		# Set volatility

#call to be longed
y1 = (log(S/K)+(r-sigma^2/2)*tau1)/(sigma*sqrt(tau1))
delta1 = pnorm(y1+sigma*sqrt(tau1))

#call to be shorted
y2 = (log(S/K)+(r-sigma^2/2)*tau2)/(sigma*sqrt(tau2))
delta2 = -pnorm(y2+sigma*sqrt(tau2))

delta = delta1+delta2 # The overall delta of the portfolio
#output

delta1
delta2
delta

#call to be longed
a1 = dnorm(y1+sigma*sqrt(tau1))
gamma1 = (1/(sigma*S*sqrt(tau1)))*a1

#call to be shorted
a2 = dnorm(y2+sigma*sqrt(tau2))
gamma2 = -(1/(sigma*S*sqrt(tau2)))*a2

gamma = gamma1+gamma2 # The overall gamma of the portfolio

#output

gamma1
gamma2
gamma


#call to be longed
t1 = -(sigma*S)/(2*sqrt(tau1))
theta1 = (t1*a1)-(r*K*exp(-r*tau1)*pnorm(y1))

#call to be shorted
t2 = -(sigma*S)/(2*sqrt(tau2))
theta2 = (t2*a2)-(r*K*exp(-r*tau2)*pnorm(y2))

theta = theta1+theta2 # The overall gamma of the portfolio

#output

theta1
theta2
theta