# ---------------------------------------------------------------------
# Book:         SFS
# ---------------------------------------------------------------------
# Quantlet:     SFSportfolio
# ---------------------------------------------------------------------
# Description:  SFSportfolio produces a PP and a QQ Plot of the daily
#               log returns from 1992-01-01 to 2006-12-29 of a portfolio of
#               Bayer, BMW and Siemens stock.
# ---------------------------------------------------------------------
# Usage:        -
# ---------------------------------------------------------------------
# Inputs:       None
# ---------------------------------------------------------------------
# Output:       Normal PP-plot and normal QQ-plot of daily log-returns of
#               portfolio (Bayer, BMW, Siemens).
# ---------------------------------------------------------------------
# Example:      -
# ---------------------------------------------------------------------
# Author:       Lasse Groth 20101008
# ---------------------------------------------------------------------
 
#Close all plots and clear variables
graphics.off()
rm(list=ls(all=TRUE))
 
#Set working directory and load data
setwd("C:/...")
x=read.table("Portf9206_logRet.dat");
 
n = nrow(x);
xf = apply(x,2,sort)  #Sort data in ascending order
 
t = (1:n)/(n+1);
dat1 = cbind(pnorm((xf-mean(xf))/sd(xf)),t); #Determine probabilities
dat2 = cbind(t,t);
 
#PP Plot
plot(dat1,col="blue",ylab=(""),xlab=c(""))
lines(dat2,col="red",lwd=2.5)
title("PP Plot of Daily Return of Portfolio")
 
#QQ Plot
dev.new()
qqnorm(xf, col="blue",xlab=c(""),ylab=c(""),main=("QQ Plot of Daily Return of Portfolio"))
qqline(xf, col="red",lwd=2.5)