# ------------------------------------------------------------------------------
# Book:        SFS
# ------------------------------------------------------------------------------
# Quantlet:    SFSstoploss
# ------------------------------------------------------------------------------
# Description: SFSstoploss calculates the Black-Scholes call price of a stock and
#              produces a table of the costs of hedging.
#
#              Refers to exercise 6.3 in SFS.
# ------------------------------------------------------------------------------
# Usage:       -
# ------------------------------------------------------------------------------
# Inputs:      None.
# ------------------------------------------------------------------------------
# Output:      Call price, table of costs of hedging.
# ------------------------------------------------------------------------------
# Example:     -
# ------------------------------------------------------------------------------
# Author:      Derrick Kanngiesser 20120403
# ------------------------------------------------------------------------------

rm(list=ls(all=TRUE))
graphics.off()


####################################    Calculates the price of the call

S = c(49,49.75,52,50,48.37,48.25,48.75,49.62,48.25,48.25,51.12,51.50,49.87,49.87,48.75,47.50,48.00,46.25,48.12,46.62,48.12)

K  = 50;
tau = 0.3846 ### 20 weeks
r  = 0.05;
sigma = 0.20;
n = 100000;

blsprice.call = function(S,K,tau,r,sigma)
{
d1 = (log(S/K)+(r-0.5*sigma^2)*tau)/(sigma*sqrt(tau))
d2 = d1+sigma*sqrt(tau)
S*pnorm(d2) - K*exp(-r*tau)*pnorm(d1)
}

C = blsprice.call(S, K, r, tau, sigma);
C

####################################    Calculates the cost of hedging
### start with 49 under a) and 51 under b)
stockprices = t(c(49,49.75,52,50,48.37,48.25,48.75,49.62,48.25,48.25,51.12,51.50,49.87,49.87,48.75,47.50,48.00,46.25,48.12,46.62,48.12))

### generate time vector
time = c(-1:20)

### generate dummy variable vector to test if stock price crosses K=50, 1==yes, 0==no
S = rbind(0,t(stockprices))
D = rbind(0,S) # vector has to start with a zero (or any number smaller than 50) in order to impose action in case the first value is greater than 50
Hedge_strat = ifelse( D>50, 1, 0 )

### hedging takes place if element changes from 0 to 1 or vice versa
### from 0 to 1 purchase
Shares_purchase = ifelse(diff(Hedge_strat)==1, 100000, 0); Shares_purchase

### from 1 to 0 sell
Shares_sold = ifelse(diff(Hedge_strat)==-1, -100000, 0); Shares_sold

###  Cost of shares, multiply number of shares (bought) with corresponding price
Cost_shares = Shares_purchase*S

###  Revenue of shares, multiply number of shares (sold) with corresponding price
Revenue_shares = Shares_sold*S

### Cumulative Costs

cumucosts = 0
for (i in 2:(length(Cost_shares))){
     	cumucosts[i] = cumucosts[i-1] + Cost_shares[i] + Revenue_shares[i]
    	print(cumucosts[i])
}

### Table of costs
tablefull = cbind(time, S,Hedge_strat[2:23],Shares_purchase,Cost_shares,Revenue_shares,cumucosts)
table = tablefull[-1,]
colnames(table) = c("Time", "Stock price", "Hedge stategy", "Shares purchased", "Cost of shares", "Revenue of shares", "Cumulativ costs")
print("Table of costs of hedging")
table
