# ------------------------------------------------------------------------------
# Book:        SFS
# ------------------------------------------------------------------------------
# Quantlet:    SFStailGPareto
# ------------------------------------------------------------------------------
# Description: SFStailGPareto estimates the parameters of a Generalized Pareto 
#              Distribution for the negative log-returns of a portfolio (Bayer, 
#              BMW, Siemens) for the time period from 1992-01-01 to 2006-09-21 
#              and produces a QQ-plot and PP-plot.
#              Corresponds to exercise 16.5 in SFS.
# ------------------------------------------------------------------------------
# Usage:       -
# ------------------------------------------------------------------------------
# Inputs:      None
# ------------------------------------------------------------------------------
# Output:      QQ-plot and PP-plot with Generalized Pareto Distribution.           
# ------------------------------------------------------------------------------
# Example:     -
# ------------------------------------------------------------------------------
# Author:      Lasse Groth 20091012
# ------------------------------------------------------------------------------
 
#Load library
install.packages("QRMlib")
library(QRMlib)
 
#Close all plots and clear variables
graphics.off()
rm(list=ls(all=TRUE))
 
#Set working directory and load datasets
setwd("C:/...")
 
a=read.table("Bay9906_close_2kPoints.txt")
b=read.table("Bmw9906_close_2kPoints.txt")
c=read.table("Sie9906_close_2kPoints.txt")
 
d=a+b+c                                                           #Create the portfolio
lg=dim(d)
x=log(d[-lg[1],])-log(d[-1,])                                   #Negative log-returns
 
n=100                                                             #Number of extreme observations
GPD=fit.GPDb(x, nextremes=n, method="ml", information="observed") #Fit the Generalized Pareto Distribution
 
t=(1:n)/(n+1)
y1=qGPD(t,GPD$par.ests[1],GPD$par.ests[2])                        #Calculate quantiles for the Generalized Pareto Distribution
GPD.POT=sort(GPD$data)-GPD$threshold                              #Peak Over Treshol values
y2=pGPD(GPD.POT, GPD$par.ests[1], GPD$par.ests[2])                #Calcualte probabilities for the generalized Pareto distribution
 
 
#Plot the QQ plot
dev.new()                                                       
plot(GPD.POT,y1,col="blue",pch=23,bg="blue",xlab=c(""),ylab=c(""))
lines(y1,y1,type="l",col="red",lwd=2)
title("QQ plot, Generalized Pareto Distribution")             
 
#Plot the PP plot
dev.new()                                                       
plot(y2,t,col="blue",pch=23,bg="blue",xlab=c(""),ylab=c(""))
lines(y2,y2,type="l",col="red",lwd=2)
title('PP plot, Generalized Pareto Distribution')