# ------------------------------------------------------------------------------
# Book:         SFS
# ------------------------------------------------------------------------------
# Quantlet:     SFStailport
# ------------------------------------------------------------------------------
# Description:  SFStailport plots the right tail of the logarithmic empirical
#               distribution of the portfolio (Bayer, BMW, Siemens) returns
#               from 1992-01-01 to 2006-09-21.
# ------------------------------------------------------------------------------
# Usage:        -
# ------------------------------------------------------------------------------
# Inputs:       None
# ------------------------------------------------------------------------------
# Output:       Right tail of the logarithmic empirical distribution of the
#               portfolio (Bayer, BMW, Siemens).
# ------------------------------------------------------------------------------
# Example:      -
# ------------------------------------------------------------------------------
# Author:       Lasse Groth 20091022
# ------------------------------------------------------------------------------
 
#Close all plots and clear variables
graphics.off()
rm(list=ls(all=TRUE))
 
#Set working directory
#setwd("C:/...")
 
a=read.table("Bay9906_close_2kPoints.txt")
b=read.table("Bmw9906_close_2kPoints.txt")
c=read.table("Sie9906_close_2kPoints.txt")
 
d=a+b+c                       #Create the portfolio
lg=dim(d)
x=log(d[-lg[1],])-log(d[-1,]) #Negative log-returns
 
n=length(x)
x=sort(x, decreasing = TRUE)
m=100
 
# Generalized least squares method
x=x[1:m]
x1=cbind(matrix(1,m,1),x)
y1=log(seq(1,m)/n)
g=solve(t(x1)%*%x1)%*%(t(x1)%*%y1)
 
line=g[1]+g[2]*x
alpha=-g[2]
gamma=1/alpha
out=cbind(x,line)
 
plot(out[,1], out[,2], type="l",xlab=("Log X"),ylab=("Log i/n"),lwd=2.5,cex.axis=1.5,cex.lab=1.5)
points(x,y1,col="blue")
title("Tail Index Regression of Portfolio",cex.main=1.5)
