# ----------------------------------------------------------------------
# Book:         SFS
# ----------------------------------------------------------------------
# Quantlet:     SFStrinomialSB
# ----------------------------------------------------------------------
# Description:  Risk neutral probabilities of the up, middle, and down
#               movements such that the price of the call option with
#               strike K is equal to the price of the hedging portfolio
#               minimizing the quadratic hedging error (see Exercise 7.5
#               in SFS) at time t = 0.
#               Corresponds to excercise 7.6 in SFS.
# ----------------------------------------------------------------------
# Usage:        -
# ----------------------------------------------------------------------
# Inputs:       S0 - stock price of one period trinomial model
#               Su, Sd, Sm - stock possible prices
#               K - strike price
# ----------------------------------------------------------------------
# Output:       Risk neutral probabilities qu, qm, qd of the up, middle, 
#               and down movements such that the price of the call option
#               with strike K is equal to the price of the hedging 
#               portfolio minimizing the quadratic hedging error
#               (see Exercise 7.5 in SFS) at time t = 0.
# ----------------------------------------------------------------------
# Example:      the example is produced for the values:
#               S0 = 100 
#               Su = 120
#               Sd = 80
#               Sm = S0
#               K = 100
# -----------------------------------------------------------------------
# Author:       Awdesch Melzer 20120510
# -----------------------------------------------------------------------

# clear variables and close windows
rm(list=ls(all=TRUE))
graphics.off()

install.packages("pracma")
library(pracma)

# stock tree
S0 = 100;
Su = 120;
Sd = 80;
Sm =S0;

# strike price
K = 100;

# payoff of the call option
Sdplus = (Sd-K)*((Sd-K)>0);
Smplus = (Sm-K)*((Sm-K)>0);
Suplus = (Su-K)*((Su-K)>0);

# hedging with minimal quadratic error 
A = rbind(cbind(Su,1),cbind(Sm,1),cbind(Sd,1));
b = rbind(Suplus,Smplus,Sdplus);
delta= mldivide(A,b);

# call option price under this hedging
call = delta[1]*S0+delta[2];

# matringale measure of this hedging
A = rbind(t(A),t(b));
b = rbind(S0,1,call);
q = mldivide(A,b)
q