# ---------------------------------------------------------------------
# Book:         SFS
# ---------------------------------------------------------------------
# Quantlet:     SFSwiener1
# ---------------------------------------------------------------------
# Description:  Simulates a Wiener Process Wt.
#               Refers to exercise 5.1 in SFS.
# ---------------------------------------------------------------------
# Usage:        -
# ---------------------------------------------------------------------
# Inputs:       dt - Delta t
# ---------------------------------------------------------------------
# Output:       plot of Wiener Process
# ---------------------------------------------------------------------
# Example:      for dt=0.001, a Wiener Process with 1000 points is 
#               generated
# ---------------------------------------------------------------------
# Notes         Plug in delta t:  1, 0.5, 0.25, ... to see how the
#               limiting process works. 
# ---------------------------------------------------------------------
# Author:       Lasse Groth 20090908
# ---------------------------------------------------------------------

wiener1=function(dt){

l=1 
n=floor(l/dt) 
t=seq(0,n*dt,dt) 

set.seed(0)
z=runif(n, min=0, max=1)
z=2*(z>0.5)-1 
z=z*sqrt(dt)   #to get finite and non-zero varinace

x=c(0,cumsum(z))
listik=cbind(t,x)

# output
plot(listik[,1],listik[,2],type="l",col="blue",xlab="Time",ylab="Values of process X_t")

title("Wiener process")
}

wiener1(0.001)