# ------------------------------------------------------------------------------
# Book:         SFS
# ------------------------------------------------------------------------------
# Quantlet:     SFSwiener2
# ------------------------------------------------------------------------------
# Description:  Simulates a Wiener Process Xt=c^(-0.5)*Wct.
#               Refers to exercise 5.1 in SFS.
# ------------------------------------------------------------------------------
# Usage:        -
# ------------------------------------------------------------------------------
# Inputs:       dt - Delta t
#               c - Constant
# ------------------------------------------------------------------------------
# Output:       plot of a Wiener Process Xt=c^(-0.5)*Wct
# ------------------------------------------------------------------------------
# Example:      for dt=0.001, c=2 a Wiener Process Xt=1/sqrt(2)*W(2t) is 
#               shown
# ------------------------------------------------------------------------------
# Notes         Plug in delta t: 1, 0.5, 0.25, ... to see how the 
#               limiting process works. 
# ------------------------------------------------------------------------------
# Author:       Lasse Groth 20090908
# ------------------------------------------------------------------------------

rm(list=ls(all=TRUE))	# Clear variables

#setwd("C:/...")	# Please change working directory

wiener2=function(dt,c){

l=1
n=floor(l/dt) 
t=seq(0,n*dt,c*dt)

set.seed(0)
z=runif(floor(n/c),0,1)  
z=2*(z>0.5)-1 
z=z*c^(-0.5)*sqrt(dt)   #to get finite and non-zero variance

x=c(0,cumsum(z))
listik=cbind(t,x)

# output
plot(listik[,1],listik[,2],type="l",col="blue",xlab="Time",ylab="Values of process X_t")
title("Wiener process") 
    
}

wiener2(0.001,2)