# ---------------------------------------------------------------------
# Book:        SFS
# ---------------------------------------------------------------------
# Quantlet:    blackscholes
#	       nested by SFShullhedgeratio.r
# ---------------------------------------------------------------------
# Description: gives values for Call and Put according to Black Scholes 
#	           
# ---------------------------------------------------------------------
# Usage:       -
# ---------------------------------------------------------------------
# Inputs:      Price, exercise price, risk-free rate, time to maturity
#	       volatility	
# ---------------------------------------------------------------------
# Output:      Black Scholes Call and Put price
# ---------------------------------------------------------------------
# Example:     -
# ---------------------------------------------------------------------
# Author:       
# ---------------------------------------------------------------------
#
# Black-Scholes Option Value
# Call value is returned in values[1], put in values[2]
blackscholes <- function(S, X, rf, T, sigma) {
    values <- c(2)
    d1 <- (log(S/X)+(rf+sigma^2/2)*T)/sigma*sqrt(T)
    d2 <- d1 - sigma * sqrt(T)
    values[1] <- S*pnorm(d1) - X*exp(-rf*T)*pnorm(d2)
    values[2] <- X*exp(-rf*T) * pnorm(-d2) - S*pnorm(-d1)
    values
}
